-----------------
Alice Bob QA
-----------------

.. literalinclude:: ../../../../../examples/user/alice_bob_qa.py
    :caption: See `alice_bob_qa.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/alice_bob_qa.py>`_ on GitHub.

-----------------
Alice Bob Talk
-----------------

.. literalinclude:: ../../../../../examples/user/alice_bob_talk.py
    :caption: See `alice_bob_talk.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/alice_bob_talk.py>`_ on GitHub.

-------------------
Complete My Code
-------------------

.. literalinclude:: ../../../../../examples/user/complete_my_code.py
    :caption: See `complete_my_code.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/complete_my_code.py>`_ on GitHub.

-------------------
Country Capital QA
-------------------

.. literalinclude:: ../../../../../examples/user/country-capital-qa.py
    :caption: See `country-capital-qa.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/country-capital-qa.py>`_ on GitHub.

-----------------
Explain my Code
-----------------

.. literalinclude:: ../../../../../examples/user/explain_my_code.py
    :caption: See `explain_my_code.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/explain_my_code.py>`_ on GitHub.

-----------------
Many Greetings
-----------------

.. literalinclude:: ../../../../../examples/user/many_greetings.py
    :caption: See `many_greetings.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/many_greetings.py>`_ on GitHub.
